==> eslint-config-theyoxy-0.0.20.tgz: package/index.js <==
module.exports = {
  root: true,
  env: {
    browser: true,
    node: true
  },
  parserOptions: {
    parser: "babel-eslint"
  },
  extends: [
    "plugin:prettier/recommended",
    "plugin:vue/recommended",
    "plugin:nuxt/recommended",
    "eslint:recommended",
    "plugin:import/errors",
    "plugin:import/warnings"
  ],
  plugins: ["vue"],
  rules: {
    "no-console": ["off"],
    "consistent-return": ["error"],
    "no-alert": ["off"],
    "no-empty-function": ["warn"],
    "init-declarations": ["error"],
    "no-label-var": ["error"],
    "no-new-require": ["error"],
    camelcase: ["error"],
    "consistent-this": ["error", "that"],
    "handle-callback-err": "off",
    "operator-linebreak": "off",
    "no-multi-assign": ["error"],
    "array-bracket-spacing": ["error", "never"],
    "block-spacing": ["error", "always"],
    "brace-style": ["error", "1tbs"],
    "capitalized-comments": ["error", "always"],
    "eol-last": ["error", "always"],
    "func-call-spacing": ["error", "never"],
    "function-call-argument-newline": ["error", "consistent"],
    "function-paren-newline": ["error", "consistent"],
    "implicit-arrow-linebreak": ["error", "beside"],
    indent: ["error", 2],
    "key-spacing": ["error", { beforeColon: false, afterColon: true }],
    "linebreak-style": ["error", "unix"],
    "new-parens": ["error", "always"],
    "no-multiple-empty-lines": ["error", { max: 2 }],
    "no-trailing-spaces": ["error"],
    "object-curly-spacing": ["error", "always"],
    "one-var": ["error", "never"],
    "one-var-declaration-per-line": ["error", "always"],
    "padded-blocks": ["error", "never"],
    "semi-spacing": ["error", { before: false, after: true }],
    "space-before-blocks": ["error", "always"],
    "space-before-function-paren": ["error", "never"],
    "arrow-parens": ["error", "as-needed"],
    "arrow-spacing": ["error", { before: true, after: true }],
    // Allow paren-less arrow functions only when there's no braces
    "arrow-parens": ["error", "as-needed", { requireForBlockBody: true }],
    // Allow async-await
    "generator-star-spacing": "off",
    // Allow debugger during development
    "no-debugger": process.env.NODE_ENV === "production" ? "error" : "warn",
    "no-console": process.env.NODE_ENV === "production" ? "error" : "warn",
    // Prefer const over let
    "prefer-const": [
      "error",
      {
        destructuring: "any",
        ignoreReadBeforeAssign: false
      }
    ],
    // No single if in an "else" block
    "no-lonely-if": "error",
    // Force curly braces for control flow,
    // including if blocks with a single statement
    curly: ["error", "all"],
    // No async function without await
    "require-await": "error",
    // Force dot notation when possible
    "dot-notation": "error",
    "no-var": "error",
    // Force object shorthand where possible
    "object-shorthand": "error",
    // No useless destructuring/importing/exporting renames
    "no-useless-rename": "error",

    // Enforce import order
    "import/order": "error",
    // Imports should come first
    "import/first": "error",
    // Other import rules
    "import/no-mutable-exports": "error",
    // Allow unresolved imports
    "import/no-unresolved": "off"
  },
  settings: {
    "import/resolver": {
      node: { extensions: [".js", ".mjs"] }
    }
  }
};

==> eslint-config-theyoxy-0.0.22.tgz: package/index.js <==
module.exports = {
  root: true,
  env: {
    browser: true,
    node: true
  },
  parserOptions: {
    parser: "babel-eslint"
  },
  extends: [
    "plugin:prettier/recommended",
    "plugin:vue/recommended",
    "plugin:nuxt/recommended",
    "eslint:recommended",
    "plugin:import/errors",
    "plugin:import/warnings"
  ],
  plugins: ["vue"],
  rules: {
    "consistent-return": ["error"],
    "no-alert": ["off"],
    "no-empty-function": ["warn"],
    "init-declarations": ["error"],
    "no-label-var": ["error"],
    "no-new-require": ["error"],
    camelcase: ["error"],
    "consistent-this": ["error", "that"],
    "handle-callback-err": "off",
    "operator-linebreak": "off",
    "no-multi-assign": ["error"],
    "array-bracket-spacing": ["error", "never"],
    "block-spacing": ["error", "always"],
    "brace-style": ["error", "1tbs"],
    "capitalized-comments": ["error", "always"],
    "eol-last": ["error", "always"],
    "func-call-spacing": ["error", "never"],
    "function-call-argument-newline": ["error", "consistent"],
    "function-paren-newline": ["error", "consistent"],
    "implicit-arrow-linebreak": "off",
    indent: ["error", 2],
    "key-spacing": ["error", { beforeColon: false, afterColon: true }],
    "linebreak-style": ["error", "unix"],
    "new-parens": ["error", "always"],
    "no-multiple-empty-lines": ["error", { max: 2 }],
    "no-trailing-spaces": ["error"],
    "object-curly-spacing": ["error", "always"],
    "one-var": ["error", "never"],
    "one-var-declaration-per-line": ["error", "always"],
    "padded-blocks": ["error", "never"],
    "semi-spacing": ["error", { before: false, after: true }],
    "space-before-blocks": ["error", "always"],
    "space-before-function-paren": ["error", "never"],
    "arrow-spacing": ["error", { before: true, after: true }],
    // Allow paren-less arrow functions only when there's no braces
    "arrow-parens": ["error", "as-needed", { requireForBlockBody: true }],
    // Allow async-await
    "generator-star-spacing": "off",
    // Allow debugger during development
    "no-debugger": process.env.NODE_ENV === "production" ? "error" : "warn",
    "no-console": process.env.NODE_ENV === "production" ? "error" : "warn",
    // Prefer const over let
    "prefer-const": [
      "error",
      {
        destructuring: "any",
        ignoreReadBeforeAssign: false
      }
    ],
    // No single if in an "else" block
    "no-lonely-if": "error",
    // Force curly braces for control flow,
    // including if blocks with a single statement
    curly: ["error", "all"],
    // No async function without await
    "require-await": "error",
    // Force dot notation when possible
    "dot-notation": "error",
    "no-var": "error",
    // Force object shorthand where possible
    "object-shorthand": "error",
    // No useless destructuring/importing/exporting renames
    "no-useless-rename": "error",

    // Enforce import order
    "import/order": "error",
    // Imports should come first
    "import/first": "error",
    // Other import rules
    "import/no-mutable-exports": "error",
    // Allow unresolved imports
    "import/no-unresolved": "off"
  },
  settings: {
    "import/resolver": {
      node: { extensions: [".js", ".mjs"] }
    }
  }
};
